@@ -41,7 +41,7 @@ def read_init_info(inps):
         inps.file_label = []
         for fname in inps.file:
             fbase = os.path.splitext(os.path.basename(fname))[0]
-            fbase = fbase.replace('timeseries', '')
+            fbase = fbase.replace('timeseries', 'TS')
             inps.file_label.append(fbase)
 
     # default mask file
@@ -127,6 +127,7 @@ def read_init_info(inps):
 
     # Map info - coordinate unit
     inps.coord_unit = atr.get('Y_UNIT', 'degrees').lower()
+    inps.lalo_digit = ut.get_lalo_digit4display(atr, coord_unit=inps.coord_unit)
     inps = view.check_map_projection(inps, metadata=atr, print_msg=inps.print_msg)
 
     # calculate multilook_num
@@ -175,10 +176,11 @@ def read_init_info(inps):
     ## initial pixel coord
     if inps.lalo:
         inps.yx = inps.coord.geo2radar(inps.lalo[0], inps.lalo[1], print_msg=False)[0:2]
-    try:
-        inps.lalo = inps.coord.radar2geo(inps.yx[0], inps.yx[1], print_msg=False)[0:2]
-    except:
-        inps.lalo = None
+    if inps.yx:
+        try:
+            inps.lalo = inps.coord.radar2geo(inps.yx[0], inps.yx[1], print_msg=False)[0:2]
+        except FileNotFoundError:
+            inps.lalo = None
 
     ## figure settings
     # Flip up-down / left-right
@@ -365,7 +367,7 @@ def plot_ts_errorbar(ax, dis_ts, inps, ppar):
 
     kwargs = dict(
         fmt='-o', ms=ppar.ms, lw=0, alpha=1,
-        elinewidth=inps.edge_width, ecolor='black',
+        elinewidth=inps.edge_width,
         capsize=ppar.ms*0.5, mew=inps.edge_width,
     )
 
@@ -380,6 +382,7 @@ def plot_ts_errorbar(ax, dis_ts, inps, ppar):
             inps.ex_dates, ex_d_ts,
             yerr=inps.ex_error_ts,
             color='gray',
+            ecolor='gray',
             **kwargs,
         )
 
@@ -389,10 +392,13 @@ def plot_ts_errorbar(ax, dis_ts, inps, ppar):
         yerr=inps.error_ts,
         label=ppar.label,
         color=ppar.mfc,
+        ecolor=ppar.mfc,
         **kwargs
     )
 
-    return ax
+    handles = ax.get_legend_handles_labels()[0]
+
+    return ax, handles[-1]
 
 
 def plot_ts_scatter(ax, dis_ts, inps, ppar):
@@ -412,8 +418,8 @@ def plot_ts_scatter(ax, dis_ts, inps, ppar):
         ax.plot(inps.ex_dates, ex_d_ts, color='gray', lw=0, **kwargs)
 
     # Plot kept dates
-    ax.plot(dates, d_ts, color=ppar.mfc, label=ppar.label, lw=inps.linewidth, **kwargs)
-    return ax
+    handle, = ax.plot(dates, d_ts, color=ppar.mfc, label=ppar.label, lw=inps.linewidth, **kwargs)
+    return ax, handle
 
 
 def plot_ts_fit(ax, ts_fit, inps, ppar, m_strs=None, ts_fit_lim=None):
@@ -449,7 +455,12 @@ def plot_ts_fit(ax, ts_fit, inps, ppar, m_strs=None, ts_fit_lim=None):
         handles += [patches.Rectangle((0, 0), 1, 1, fc="white", ec="white", lw=0, alpha=0)] * len(m_strs)
         labels += [re.sub(' +', ' ', x) for x in m_strs]
 
-    if len(labels) > 0:
+    # do not print model parameters for multi files [temporarily]
+    # solutions:
+    # 1. plot multiple legends, need to find out how to layout them, otherwise they would overlap on top of each other
+    #    link: https://matplotlib.org/stable/tutorials/intermediate/legend_guide.html#multiple-legends-on-the-same-axes
+    # 2. update the same legend, by saving the handles and labels for all files
+    if len(labels) > 0 and len(inps.file) == 1:
         ax.legend(handles, labels, **kwargs)
 
     return ax
@@ -557,14 +568,21 @@ def fit_time_func(model, date_list, ts_dis, disp_unit='cm', G_fit=None, conf_lev
     return m_strs, ts_fit, ts_fit_lim
 
 
-def get_ts_title(y, x, coord_obj):
-    title = f'Y/X = {y}, {x}'
+def get_point_coord_str(y, x, coord_obj, lalo_digit=5):
+    """Get the string of the point coordinates.
+
+    Parameters: y / x      - int, row / column number
+                coord_obj  - mintpy.objects.coordinate object
+                lalo_digit - int, digit of the decimal place for lat/lon
+    Returns:    pts_str    - str, point coordinate string
+    """
+    coord_str = f'Y/X = {y}, {x}'
     try:
         lat, lon = coord_obj.radar2geo(y, x, print_msg=False)[0:2]
-        title += f', lat/lon = {lat:.4f}, {lon:.4f}'
-    except:
+        coord_str += f', lat/lon = {lat:.{lalo_digit}f}, {lon:.{lalo_digit}f}'
+    except FileNotFoundError:
         pass
-    return title
+    return coord_str
 
 
 def save_ts_data_and_plot(yx, d_ts, m_strs, inps):
@@ -585,7 +603,7 @@ def save_ts_data_and_plot(yx, d_ts, m_strs, inps):
     # TXT - point time-series and time func param
     outName = f'{inps.outfile_base}_ts.txt'
     header = f'time-series file = {inps.file[0]}\n'
-    header += f'{get_ts_title(y, x, inps.coord)}\n'
+    header += f'{get_point_coord_str(y, x, inps.coord, inps.lalo_digit)}\n'
     header += f'reference pixel: y={inps.ref_yx[0]}, x={inps.ref_yx[1]}\n' if inps.ref_yx else ''
     header += f'reference date: {inps.date_list[inps.ref_idx]}\n' if inps.ref_idx else ''
     header += 'estimated time function parameters:\n'
@@ -867,6 +885,7 @@ class timeseriesViewer():
         # get local Y/X coord for the subsetted and multilooked 3D data cube
         (y, x) = subset_and_multilook_yx(yx, self.pix_box, self.multilook_num)
 
+        handles, labels = [], []
         for i in range(num_file-1, -1, -1):
             # get displacement data
             ts_dis = self.ts_data[i][:, y, x]
@@ -874,8 +893,8 @@ class timeseriesViewer():
             # fit time func
             m_strs, ts_fit, ts_fit_lim = fit_time_func(
                 model=self.model,
-                date_list=self.date_list,
-                ts_dis=ts_dis,
+                date_list=np.array(self.date_list)[self.ex_flag].tolist(),
+                ts_dis=ts_dis[self.ex_flag],
                 disp_unit=self.disp_unit,
                 G_fit=self.G_fit,
                 seconds=self.seconds)
@@ -893,12 +912,14 @@ class timeseriesViewer():
             if not np.all(np.isnan(ts_dis)):
                 ppar = argparse.Namespace()
                 ppar.label = self.file_label[i]
-                ppar.mfc = pp.mplColors[num_file - 1 - i] if self.mask[y, x] != 0 else 'gray'
+                ppar.mfc = f'C{num_file-1-i}' if self.mask[y, x] != 0 else 'gray'
                 ppar.ms = self.marker_size - ms_step * (num_file - 1 - i)
                 # use smaller marker size for very long time series
-                if self.num_date > 1e3:
-                    ppar.ms /= 10
-                self.ts_plot_func(ax, ts_dis, self, ppar)
+                ppar.ms /= 10 if self.num_date > 1e3 else 1
+
+                handle = self.ts_plot_func(ax, ts_dis, self, ppar)[1]
+                handles.append(handle)
+                labels.append(ppar.label)
 
                 # plot model prediction
                 if self.plot_model:
@@ -927,14 +948,14 @@ class timeseriesViewer():
             ax.yaxis.set_label_position("right")
 
         # title
-        title = get_ts_title(yx[0], yx[1], self.coord)
+        title = get_point_coord_str(yx[0], yx[1], self.coord, self.lalo_digit)
         title += ' (masked out)' if self.mask[y, x] == 0 else ''
         if self.disp_title:
             ax.set_title(title, fontsize=self.font_size)
 
         # legend
         if len(self.ts_data) > 1:
-            ax.legend()
+            ax.legend(handles, labels)
 
         # Print to terminal
         vprint('\n---------------------------------------')
