@@ -13,8 +13,8 @@ import os
 import re
 import sys
 import warnings
+import xml.etree.ElementTree as ET
 
-import defusedxml.ElementTree as ET
 import h5py
 import numpy as np
 
@@ -880,7 +880,7 @@ def get_hdf5_dataset_attrs(fname, key='UNIT'):
 
     fext = os.path.splitext(fname)[1]
     if fext not in ['.h5', '.he5']:
-        raise ValueError(f'input file ({fname}) does not end with .h5/he5!')
+        return None
 
     # default output: empty
     attrs = {}
@@ -1178,7 +1178,7 @@ def read_attribute(fname, datasetName=None, metafile_ext=None):
 
         # Read metadata file and FILE_TYPE
         metafile = metafiles[0]
-        meta_ext = os.path.splitext(metafile)[1]
+        meta_ext = os.path.splitext(metafile)[1].lower()
 
         # ignore certain meaningless file extensions
         while fext in ['.geo', '.rdr', '.full', '.wgs84', '.grd']:
