@@ -343,8 +343,6 @@ def to_latlon(infile, x, y):
     return y, x
 
 
-
-
 def snwe_to_wkt_polygon(snwe):
     """Convert the input bounding box in SNWE into WKT format POLYGON.
 
@@ -476,6 +474,47 @@ def four_corners(atr):
     return south, north, west, east
 
 
+def get_lalo_digit4display(meta, coord_unit='degree'):
+    """Get the digit of the decimal place for the lat/lon info for display (e.g., at the status bar).
+
+    Parameters: meta       - dict, metadata for the following attributes:
+                             X_STEP
+                             Y_STEP
+                             RANGE_PIXEL_SIZE
+                             AZIMUTH_PIXEL_SIZE
+                coord_unit - str, coordinate unit, degree or meter
+    Returns:    digit      - int, the digit for the decimal places of lat/lon
+    """
+
+    if coord_unit.startswith('meter'):
+        digit = 2
+
+    else:
+        geo_step_keys = ['X_STEP', 'Y_STEP']
+        rdr_step_keys = ['RANGE_PIXEL_SIZE', 'AZIMUTH_PIXEL_SIZE']
+
+        # get step size in degree
+        if all(x in meta.keys() for x in geo_step_keys):
+            min_step = min([abs(float(meta[x])) for x in geo_step_keys])
+
+        elif all(x in meta.keys() for x in rdr_step_keys):
+            # default scaling for spaceborne system to ground range / azimuth
+            rg_pix_size = float(meta['RANGE_PIXEL_SIZE']) / np.cos(np.deg2rad(30))
+            az_pix_size = float(meta['AZIMUTH_PIXEL_SIZE']) * 0.9
+            min_step = min([rg_pix_size, az_pix_size]) / 108e3
+        else:
+            # default pixel size 30 m
+            min_step = 30 / 108e3
+
+        # set the decimal place one order   (precision for step-range)
+        if   min_step >= 2e-2:  digit = 3  # 110  m for >2.2 km
+        elif min_step >= 2e-3:  digit = 4  # 11   m for >220 m
+        elif min_step >= 2e-4:  digit = 5  # 1    m for >22  m
+        elif min_step >= 2e-5:  digit = 6  # 0.1  m for >2.2 m
+        else:                   digit = 7  # 0.01 m for <2.2 m
+
+    return digit
+
 
 ###################################### Orbit ###########################################
 def xyz_to_local_radius(xyz):
@@ -729,6 +768,17 @@ def wrap(data_in, wrap_range=[-1.*np.pi, np.pi]):
     return data
 
 
+def diff_wrapped_phase(pha1, pha2):
+    """Calculate the difference between two input wrapped phase.
+
+    Parameters: pha1     - np.ndarray, (un)wrapped phase
+                pha2     - np.ndarray / float, (un)wrapped phase
+    Returns:    pha_diff - np.ndarray, wrapped phase difference for (pha1 - pha2)
+    """
+    pha_diff = np.angle(np.exp(-1j * pha1) * np.conj(np.exp(-1j * pha2)))
+    return pha_diff
+
+
 def get_all_conn_components(mask_in, min_num_pixel=1e4):
     """Get all connected component with number of pixels larger than threshold
     Parameters: mask_in  : 2D np.array with zero as background and non-zero as foreground
@@ -765,7 +815,7 @@ def get_largest_conn_component(mask_in, min_num_pixel=1e4, display=False):
     max_label = np.argmax(np.bincount(labels.flatten())[1:]) + 1
     mask_out = labels == max_label
     if display:
-        fig, ax = plt.subplots(nrows=1, ncols=3, figsize=[15, 5])
+        _, ax = plt.subplots(nrows=1, ncols=3, figsize=[15, 5])
         ax[0].imshow(mask_in)
         ax[1].imshow(mask_out)
         ax[2].imshow(mask_in ^ mask_out)
@@ -805,23 +855,37 @@ def min_region_distance(mask1, mask2, display=False):
     return xy1, xy2, min_dist
 
 
-def interpolate_data(inData, outShape, interpMethod='linear'):
+def interpolate_data(in_data, out_shape, interp_method='linear'):
     """Interpolate input 2D matrix into different shape.
+
     Used to get full resolution perp baseline from ISCE coarse grid baseline file.
-    Parameters: inData : 2D array
-                outShape : tuple of 2 int in (length, width)
-                interpMethod : string, choose in [nearest, linear, cubic]
-    Returns:    outData : 2D array in outShape
+
+    Parameters: in_data       : 2D np.ndarray
+                out_shape     : tuple of 2 int in (length, width)
+                interp_method : string, choose in [nearest, linear, cubic]
+    Returns:    out_data      : 2D np.ndarray in out_shape
     """
-    from scipy.interpolate import RegularGridInterpolator as RGI
-    inShape = inData.shape
-    inPts = (np.arange(inShape[0]), np.arange(inShape[1]))
-    xx, yy = np.meshgrid(np.linspace(0, inShape[1]-1, outShape[1], endpoint=False),
-                         np.linspace(0, inShape[0]-1, outShape[0], endpoint=False))
-    outPts = np.hstack((yy.reshape(-1, 1), xx.reshape(-1, 1)))
-    outData = RGI(inPts, inData, method=interpMethod,
-                  bounds_error=False)(outPts).reshape(outShape)
-    return outData
+    from scipy.interpolate import RegularGridInterpolator
+
+    # prepare interpolation function
+    in_shape = in_data.shape
+    in_pts = (np.arange(in_shape[0]), np.arange(in_shape[1]))
+    interp_func = RegularGridInterpolator(
+        in_pts,
+        in_data,
+        method=interp_method,
+        bounds_error=False,
+    )
+
+    # prepare output coordinates
+    xx, yy = np.meshgrid(np.linspace(0, in_shape[1]-1, out_shape[1], endpoint=False),
+                         np.linspace(0, in_shape[0]-1, out_shape[0], endpoint=False))
+    out_pts = np.hstack((yy.reshape(-1, 1), xx.reshape(-1, 1)))
+
+    # run interpolation
+    out_data = interp_func(out_pts).reshape(out_shape)
+
+    return out_data
 
 
 def polygon2mask(polygon, shape):
